// File: content_v1.js
// Description: Listens for a saveText message, extracts chat text, and saves it with a custom prefix and LM identifier (ChatGPT or Grok).

// Log injection
console.log("Content script injected!");

// Message listener
chrome.runtime.onMessage.addListener(function(request, sender, sendResponse) {
    console.log("Message received:", request);
    if (request.action === "saveText") {
        try {
            // Determine the language model from the URL
            var url = window.location.href;
            var lmTag = url.includes("chatgpt.com") ? "ChatGPT" : "Grok";
            console.log("Detected LM:", lmTag);

            // Chat content selector (tweak after inspection if needed)
            var chatContentElement = document.querySelector(".messages") || document.querySelector("section") || document.querySelector("main");
            console.log("Chat element found:", chatContentElement);
            if (!chatContentElement) {
                console.error("No chat content element found.");
                sendResponse({ status: "error", message: "Chat content not found." });
                return;
            }

            var chatTitleElement = document.querySelector("h1") || document.querySelector(".title");
            var chatTitle = chatTitleElement ? chatTitleElement.innerText.trim() : `${lmTag}_Chat`;
            console.log("Chat title:", chatTitle);
            chatTitle = chatTitle.replace(/[/\\?%*:|"<>]/g, '_');

            var chatText = chatContentElement.innerText.trim();
            console.log("Captured text:", chatText);
            if (!chatText) {
                console.error("No chat text captured.");
                sendResponse({ status: "error", message: "No chat text to save." });
                return;
            }

            // Build filename with optional prefix
            var prefix = request.prefix ? request.prefix.replace(/[/\\?%*:|"<>]/g, '_') + "_" : "";
            const now = new Date();
            const timestamp = now.toISOString().replace(/[:\-]|\.\d{3}/g, '');
            const filename = `${prefix}${chatTitle}_${lmTag}_${timestamp}.txt`;
            console.log("Saving file:", filename);

            var blob = new Blob([chatText], { type: "text/plain" });
            var url = URL.createObjectURL(blob);
            var a = document.createElement('a');
            a.href = url;
            a.download = filename;
            document.body.appendChild(a);
            a.click();
            document.body.removeChild(a);
            URL.revokeObjectURL(url);

            console.log("File saved successfully.");
            sendResponse({ status: "success" });
        } catch (error) {
            console.error("Error saving chat:", error);
            sendResponse({ status: "error", message: error.message });
        }
    }
});