// File: popup_v1.js
// Description: Triggers a page reload, injects content.js, and sends a save message with a custom prefix for ChatGPT or Grok chats.

// Event listener for the save button
document.getElementById('saveBtn').addEventListener('click', function() {
    chrome.tabs.query({active: true, currentWindow: true}, function(tabs) {
        var currentTab = tabs[0];
        var url = currentTab.url;
        if (url && (url.startsWith("https://chatgpt.com/") || url.startsWith("https://x.com/i/grok"))) {
            var prefix = document.getElementById('prefixInput').value.trim();
            document.getElementById('status').textContent = "Reloading page...";
            console.log("Reloading tab:", currentTab.id);
            chrome.tabs.reload(currentTab.id, {}, function() {
                setTimeout(() => {
                    document.getElementById('status').textContent = "Injecting script...";
                    console.log("Injecting content.js into tab:", currentTab.id);
                    chrome.scripting.executeScript({
                        target: { tabId: currentTab.id },
                        files: ['content.js']
                    }, () => {
                        if (chrome.runtime.lastError) {
                            document.getElementById('status').textContent = "Injection error: " + chrome.runtime.lastError.message;
                            console.error("Injection failed:", chrome.runtime.lastError.message);
                            return;
                        }
                        document.getElementById('status').textContent = "Saving chat...";
                        console.log("Sending saveText message with prefix:", prefix);
                        chrome.tabs.sendMessage(currentTab.id, { 
                            action: "saveText",
                            prefix: prefix
                        }, function(response) {
                            if (chrome.runtime.lastError) {
                                document.getElementById('status').textContent = "Error: " + chrome.runtime.lastError.message;
                                console.error("Message failed:", chrome.runtime.lastError.message);
                            } else if (response?.status === "success") {
                                document.getElementById('status').textContent = "Chat saved successfully.";
                                console.log("Chat saved successfully.");
                            } else {
                                document.getElementById('status').textContent = "Error: " + (response?.message || "No response.");
                                console.log("Save failed:", response?.message || "No response");
                            }
                        });
                    });
                }, 5000); // 5s delay for slow loads
            });
        } else {
            document.getElementById('status').textContent = "Works only on ChatGPT or Grok chat pages.";
            console.log("Not a supported chat page:", url);
        }
    });
});